@@ -172,6 +172,12 @@ class BufferManager(object):
     def __repr__(self):
         return '<BufferManager>'
 
+    def __getitem__(self, key):
+        """ Short-hand access for getBufferFromSymbol() i.e. Samples['x'] """
+        if isinstance(key, tuple):
+            return self.getBufferFromSymbol(*key)
+        return self.getBufferFromSymbol(key)
+
     def _reset_buffers(self):
         """ Clears the cache of loaded buffers """
         files = list(self._fn_to_buf.keys())
@@ -445,6 +451,19 @@ class LoopSynthDef(SampleSynthDef):
         proxy.kwargs["filename"] = filename
         return proxy
 
+class StretchSynthDef(SampleSynthDef):
+    def __init__(self):
+        SampleSynthDef.__init__(self, "stretch")
+        self.base.append("osc = Warp1.ar(2, buf, Line.kr(0,1,sus), rate, windowSize: 0.2, overlaps: 4, interp:2);")
+        self.base.append("osc = osc * EnvGen.ar(Env([0,1,1,0],[0.05, sus-0.05, 0.05]));")
+        self.osc = self.osc * self.amp
+        self.add()
+    def __call__(self, filename, pos=0, sample=0, **kwargs):
+        kwargs["buf"] = Samples.loadBuffer(filename, sample)
+        proxy = SampleSynthDef.__call__(self, pos, **kwargs)
+        proxy.kwargs["filename"] = filename
+        return proxy
+
 class GranularSynthDef(SampleSynthDef):
     def __init__(self):
         SampleSynthDef.__init__(self, "gsynth")
@@ -461,4 +480,5 @@ class GranularSynthDef(SampleSynthDef):
         return SampleSynthDef.__call__(self, pos, **kwargs)
 
 loop = LoopSynthDef()
+stretch = StretchSynthDef()
 # gsynth = GranularSynthDef()
\ No newline at end of file
